==> gwt-mt-widgets-0.55.5.jar: de/knightsoftnet/mtwidgets/client/ui/widget/RangeBox.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package de.knightsoftnet.mtwidgets.client.ui.widget;

import de.knightsoftnet.mtwidgets.client.ui.handler.HandlerFactory;
import de.knightsoftnet.mtwidgets.client.ui.widget.helper.IntegerParserWithoutSeparator;
import de.knightsoftnet.mtwidgets.client.ui.widget.helper.IntegerRendererWithoutSeparator;

import elemental.client.Browser;

/**
 * html 5 input range box.
 *
 * @author Manfred Tremmel
 *
 */
public class RangeBox extends AbstractMinMaxTextBox<Integer> {

  /**
   * default constructor.
   */
  public RangeBox() {
    super(Browser.getDocument().createInputElement(), "range",
        IntegerRendererWithoutSeparator.instance(), IntegerParserWithoutSeparator.instance(),
        HandlerFactory.getNumericKeyPressHandler());
  }
}

==> gwt-mt-widgets-2.0.17.jar: de/knightsoftnet/mtwidgets/client/ui/widget/RangeBox.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package de.knightsoftnet.mtwidgets.client.ui.widget;

import de.knightsoftnet.mtwidgets.client.ui.handler.HandlerFactory;
import de.knightsoftnet.mtwidgets.client.ui.widget.helper.IntegerParserWithoutSeparator;
import de.knightsoftnet.mtwidgets.client.ui.widget.helper.IntegerRendererWithoutSeparator;

import elemental2.dom.DomGlobal;
import elemental2.dom.HTMLInputElement;

/**
 * html 5 input range box.
 *
 * @author Manfred Tremmel
 *
 */
public class RangeBox extends AbstractMinMaxTextBox<Integer> {

  /**
   * default constructor.
   */
  public RangeBox() {
    super((HTMLInputElement) DomGlobal.document.createElement("input"), "range",
        IntegerRendererWithoutSeparator.instance(), IntegerParserWithoutSeparator.instance(),
        HandlerFactory.getNumericKeyPressHandler());
  }
}
